@@ -112,7 +112,8 @@ def validate_resource_constraints(generated_results):
         for container in deploy["spec"]["template"]["spec"]["containers"]:
             if "resources" not in container:
                 raise Exception(
-                    f"No resource specifications set for {deploy['kind']}: {deploy['metadata']['name']}"
+                    "No resource specifications set for "
+                    f"{deploy['kind']}: {deploy['metadata']['name']}"
                 )
 
 
@@ -169,7 +170,10 @@ def format_resources(helm_info, warn=True):
         or "limits" in helm_info["values"]["resources"]
     ) and warn:
         click.secho(
-            "Usage of 'limits' and 'requests' in templates is deprecated; please specify resource constraints in a single 'resources' block",
+            (
+                "Usage of 'limits' and 'requests' in templates is deprecated; "
+                "please specify resource constraints in a single 'resources' block"
+            ),
             fg="yellow",
         )
 
@@ -203,7 +207,7 @@ def format_resources(helm_info, warn=True):
 
 
 def render_from_local(
-    deployment_root, templates_dir, cluster, services_yaml, input_yaml, service=None
+    deployment_root, templates_dir, cluster, services_yaml, input_yaml, services=None
 ):
     generated = deployment_root / "generated"
     click.secho(f"clearing {generated}", fg="yellow")
@@ -219,7 +223,7 @@ def render_from_local(
 
     with _resolve_values(configs) as resolved_str:
         for resource, helm_info in configs["services"].items():
-            if service and service not in resource:
+            if services and not any(service in resource for service in services):
                 continue
 
             helm_info["values"] = helm_info.get("values", {})
@@ -274,7 +278,8 @@ def _resolve_remote(deployment_root, remote_path):
     os.makedirs(local_directory / "templates", exist_ok=True)
 
     run_cmd(
-        f"wget {remote_templates_path} -O - | tar -xz -C {local_directory / 'templates'}"
+        f"wget {remote_templates_path} -O - | "
+        f"tar -xz -C {local_directory / 'templates'}"
     )
     run_cmd(f"wget {remote_services_yaml} -O {local_directory / 'services.yaml'}")
     return (local_directory / "services.yaml", local_directory / "templates")
@@ -282,17 +287,17 @@ def _resolve_remote(deployment_root, remote_path):
 
 @click.command("render")
 @click.pass_context
-@click.argument("service", required=False)
+@click.argument("services", required=False, nargs=-1)
 @click.option(
     "-r",
     "--remote-configs",
-    help="Remote GCS folder with configs to render from. Ex: 'latest' or 'master.24235243'",
+    help="Remote GCS folder with configs to render from. Ex: 'latest' or 'master.2423'",
 )
 @click.option("--local", is_flag=True, help="Use local services yaml for rendering")
 @options_wrapper()
 def render(
     ctx,
-    service=None,
+    services=None,
     *,
     deployment_root,
     cluster,
@@ -341,7 +346,7 @@ def render(
 
     with tempfile.NamedTemporaryFile(suffix=".tmp", delete=False) as input_yaml:
 
-        # We keep track of which custom images were applied. We only use these to override
+        # Keep track of which custom images were applied. We only use these to override
         # generated images in the templates if specified
         # Generally not used unless we're recovering to a previous state
         old_conf = cluster_manager.clean_services()
@@ -358,7 +363,7 @@ def render(
                 cluster,
                 services_yaml,
                 input_yaml.name,
-                service=service,
+                services=services,
             )
             input_yaml.seek(0)
             cluster_manager.edit_cluster_config(
